
%% main program - Theoretical Analysis of a QEPAS sensor

% This code was writen to store the parameters and call the M function
% to compute the Signal Strength and Phase. The numerics are explained in
% details in Numerics.pdf and the constant for the WE in the Dimensions.pdf
% file.
% 
% AUTHOR: Noemi Zakarias 
% DATE: 11/08/2007
% UPDATED: 7/11/2008


%% This section contains all the parameters for 32.8 kHz (60 Torr). 
clc; clear all; close all; 
    
%problem's parameters
params.sigma            =  0.05*10^(-3);          % (m)
params.c                =  346;                   % (m/s)
f                       =  32764.43;              % (Hz = 1/s)
params.omega            =  2*pi*f;                % (1/s)
params.k                =  params.omega/params.c; % (1/m)
params.scale            =  1.0e+13;

%TF params;
params.Q                =  28887; %Quality factor % dimensionless
params.T                =  0.34*10^-3;            % (m)
params.L                =  3.8*10^-3;             % (m)
params.W                =  0.6*10^-3;             % (m)
params.x0               =  0.15*10^-3; %g/2       % (m)
params.x1               =  0.75*10^-3; %W+g/2     % (m)

% Euler_Bernoulli eq. parameters
T                       =  params.T;              % (m)
W                       =  params.W;              % (m)
params.E                =  7.87*10^10;            % (N/m^2 = Pa)
params.I                =  T*W*W*W/12;            % (m^4)
params.A                =  T*W;                   % (m^2)
params.ro               =  2.65*10^3;              % (kg/m^3) !Calculated density is 2.65*10^3
params.cc               =  (params.E*params.I/(params.ro*params.A))^0.25; %(m/s^1/2) cc 
                            % this cc stands for "a" in the EB_damping writeup
params.lambda0          =  1.875104/params.L;     % (1/m) I. 1.87510406898314 II.4.694091 %eigenvalue
%params.omega0          =  params.cc * params.cc * params.lambda0 * params.lambda0
params.omega0           =  params.omega; %params.lambda0^2*params.W*sqrt(params.E/params.ro)/sqrt(12); %(1/s)
params.gamma0           =  0.5*params.omega0/params.Q; %(1/s)

%program's params
params.rtol_alpha       =  5*1.0e-5;
params.rtol_beta        =  5*1.0e-5;
params.int_precision    =  1.0e-9;

%piezoelectric constants;
params.k_spring         =  params.E*params.T*params.W^3/(4*params.L^3); % (N/m)
params.R                =  62*10^3;

params.LL               =  params.Q*params.R/params.omega; %(Ohm = Nms/C^2)                  % (1/s)
params.m                =  0.25*params.ro*params.T*params.W*params.L;
params.gammaK           =  params.omega/params.Q;
%params.Ialpha           =  (1/params.omega)*sqrt((params.k_spring*params.gammaK)/(2*params.R));

params.Ialpha           =  7e-006; %(1/params.omega)*sqrt((params.k_spring*params.gamma0)/(params.R));% (C/m)
params.Walpha           =  9.57*10^-5*10^2;                             % (1/m)
params.W_L              =  62.1*10^-3;                                  % (Watt = Nm/s)                  
params

%% This part computes the Signal Strength (A) versus Beam Position [mm] and Phase 

% Signal constants;
const1                  = (0.5*pi/(params.c^2))/sqrt((params.omega0^2-params.omega^2)^2 ...
                           + 4*(params.gamma0*params.omega)^2)             %(s^4/m^2)
A_0                     =  10^-13*0.5*0.4*params.Walpha*params.omega*params.W_L/(2*pi*params.sigma^2) % (N/m^2s^2)
phi_0                   =  feval(@Phi0, params, params.L)
const                   =  (-params.omega)*params.Ialpha*phi_0*const1*A_0  %(A kg/m^4)

% Compute the Signal Strength (corresponding to (19) in the paper) and
% Phase (given by \delta in (17)).

load data/MagMValues_tol10to9_tor60.mat; %stores |M_*(0,y_0)| (units m^4/kg ), ReM, ImM and ty(y_0) 
Th_Signal_60torr       = 2*const*MagM;          % A kg/m^4 * m^4/kg = A
Th_Phase_60            = zeros(1,length(ty));
for i = 1:length(ty)
     Th_Phase_60torr(i) = 180/pi*atan2(ReM(i),ImM(i));   
end  

% EXPERIMENTAL DATA - 60 torr  
importfile('data/Data60Torr.txt');
y_60torr       = Data60Torr(:, 2);
Signal_60torr  = Data60Torr(:, 4);
Phase_60torr   = Data60Torr(:, 5);

%% Compares the theoretical and experimental results.

% PLOT the Signal Strength (A) versus Beam Position [mm] 
max(Th_Signal_60torr*10^12)
max(sqrt(2)*1.85*10^-4*Signal_60torr)
figure ('DefaultAxesFontSize',16); hold on; box on;
    plot(y_60torr, sqrt(2)*1.85*10^-4*Signal_60torr, 'k*','LineWidth',2, 'MarkerSize',6); 
    xlabel('Beam Position (mm)','LineWidth',2); ylabel('Signal Strength (pA)');
    set(gca,'XTick',[0 1 2 3 4 5]);               
    xlim([0 5]);

% PLOT the PHASE 
figure ('DefaultAxesFontSize',16); hold on; box on;
    plot(y_60torr, Phase_60torr-34, 'k*','LineWidth',2); %2.5
    plot(ty*1000, Th_Phase_60torr, 'k','LineWidth',2);         
    xlim([0 5]);
    xlabel('Beam Position (mm)','LineWidth',2); ylabel('Phase (degrees)');
    set(gca,'XTick',[0 1 2 3 4 5]);
    set(gca,'YTick',[-100 -80 -60 -40 -20 0 20 40 60 80 100 120]);    
    ylim([-100 120]);