% fRec1.m
% This function returns the integral for Re(c1) given by (10)in the "Wave
% Equation in cylindrical coordinates" dated on July, 17 2007
%
% Author: Noemi Zakarias
% Date: 08/01/2007
function [ fRec1out ] = fRec1( params, r )

  [m,n]=size(r);
  %preallocate fRec1
  fRec1out = zeros(m,n);

  for i=1:m
    for j=1:n
      fRec1out(i,j) = fRec1s(params, r(i,j));
    end
  end
end


%scalar version of the function
function fRec1sout = fRec1s(params, rs)
  %params aliases
  precis= params.int_precision;
  
  %handle to integrand
  fhandle = @(s)integrnd(s, params);
  %compute the int_0^rs
  fRec1sout = quad(fhandle, eps, rs, precis);
end

%integrand function
function out = integrnd(s, params)
  %params aliases
  sigma = params.sigma;
  k     = params.k;
  two_sigma_square = 2*sigma*sigma;
  
  out = params.scale*s.*(bessely(0,k*s).*exp(-s.*s/two_sigma_square));
end  
